==> cryptofont-0.1.0.tgz: package/README.md <==
CryptoFont 0.1.0
================

A sleek webfont for your favourite cryptocurrencies.

## Getting Started

```html
<i class="cf cf-btc"></i> Bitcoin
```

**Get started at [AlexanderPoellmann.com/CryptoFont](https://AlexanderPoellmann.com/CryptoFont)!**

## Check out [PaymentFont](https://github.com/AlexanderPoellmann/PaymentFont)

Looking for a sleek webfont featuring your favourite payment operators and methods? **Check out [PaymentFont](https://github.com/AlexanderPoellmann/PaymentFont)!**

## Changelog

- 2017-06-24 v0.0.1 Initial release. (88 icons)
- 2017-06-25 v0.0.2 Minor tweaks.
- 2017-06-25 v0.0.3 Update version number.
- 2017-06-25 v0.1.0 Pre-release.

## Donate

CryptoFont was useful to you? Awesome! So, why not buy me a beer to keep the project going?

- **[Donate Bitcoins](https://www.coinbase.com/checkouts/b49f0248be35b6bd5629df8c3a8c5e10)**
- **[Donate with PayPal](https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=donate@vendocr.at&currency_code=EUR&amount=&return=&item_name=Buy+me+a+beer!)**

## License

- The font is licensed under the SIL OFL 1.1:
  - http://scripts.sil.org/OFL
- The CSS files are licensed under the MIT License:
  - http://opensource.org/licenses/mit-license.html
- Attribution is not required, but much appreciated:
  - CryptoFont by @AMPoellmann - https://AlexanderPoellmann.com/CryptoFont

## Disclaimer

All used trademarks, brands and/or names are the property of their respective owners.
The use of these trademarks, brands and/or names does not indicate endorsement of the property holder by us, nor vice versa.

## Author

**Handcrafted with love by [Alexander Manfred Pöllmann](https://AlexanderPoellmann.com) in Vienna &amp; Rome.**

Follow me on [Twitter](https://twitter.com/AMPoellmann), [Instagram](https://instagram.com/AlexanderPoellmann) and [GitHub](https://github.com/AlexanderPoellmann) :-)

[![Analytics](https://ga-beacon.appspot.com/UA-57742328-1/AlexanderPoellmann/CryptoFont)](https://github.com/igrigorik/ga-beacon)

==> cryptofont-0.1.1.tgz: package/README.md <==
CryptoFont 0.1.1
================

A sleek webfont for your favourite cryptocurrencies.

## Getting Started

**Install with Bower**

```bash
$ bower install cryptofont
```

**Install with npm**

```bash
$ npm install cryptofont
```

**Install with Composer**

```bash
$ composer require alexanderpoellmann/cryptofont
```

Then copy the font files into your project, include the CSS file or import the Sass/Less file and there you go, now you can place the icons wherever you want like so:

```html
<i class="cf cf-btc"></i> Bitcoin
```

**Get started at [CryptoFont.com](https://AlexanderPoellmann.com/CryptoFont)!**

## Check out [PaymentFont](https://github.com/AlexanderPoellmann/PaymentFont)

Looking for a sleek webfont featuring your favourite payment operators and methods? **Check out [PaymentFont](https://github.com/AlexanderPoellmann/PaymentFont)!**

## Changelog

- 2017-06-24 v0.0.1 Initial release. (88 icons)
- 2017-06-25 v0.0.2 Minor tweaks.
- 2017-06-25 v0.0.3 Update version number.
- 2017-06-25 v0.1.0 Pre-release.
- 2017-07-01 v0.1.1 Add Less files.

## Donate

CryptoFont was useful to you? Awesome! So, why not buy me a beer to keep the project going?

- **[Donate Bitcoins](https://www.coinbase.com/checkouts/b49f0248be35b6bd5629df8c3a8c5e10)**
- **[Donate with PayPal](https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=donate@vendocr.at&currency_code=EUR&amount=&return=&item_name=Buy+me+a+beer!)**

## License

- The font is licensed under the SIL OFL 1.1:
  - http://scripts.sil.org/OFL
- The CSS files are licensed under the MIT License:
  - http://opensource.org/licenses/mit-license.html
- Attribution is not required, but much appreciated:
  - CryptoFont by @AMPoellmann - https://AlexanderPoellmann.com/CryptoFont

## Disclaimer

All used trademarks, brands and/or names are the property of their respective owners.
The use of these trademarks, brands and/or names does not indicate endorsement of the property holder by us, nor vice versa.

## Author

**Handcrafted with love by [Alexander Manfred Pöllmann](https://AlexanderPoellmann.com) in Vienna &amp; Rome.**

Follow me on [Twitter](https://twitter.com/AMPoellmann), [Instagram](https://instagram.com/AlexanderPoellmann) and [GitHub](https://github.com/AlexanderPoellmann) :-)

[![Analytics](https://ga-beacon.appspot.com/UA-57742328-1/AlexanderPoellmann/CryptoFont)](https://github.com/igrigorik/ga-beacon)
